@@ -40,8 +40,6 @@
 #define DISPLAY_FILENO (STDERR_FILENO + 1)
 #define BUS_ADDRESS_FILENO (DISPLAY_FILENO + 1)
 
-#define DBUS_DAEMON BINDIR "/dbus-daemon"
-
 typedef struct
 {
         GdmSettings  *settings;
@@ -195,11 +193,11 @@ spawn_x_server (State        *state,
                 gboolean      allow_remote_connections,
                 GCancellable *cancellable)
 {
-        GPtrArray           *arguments;
-        GSubprocessLauncher *launcher;
-        GSubprocess         *subprocess;
-        GInputStream        *input_stream;
-        GDataInputStream    *data_stream;
+        GPtrArray           *arguments = NULL;
+        GSubprocessLauncher *launcher = NULL;
+        GSubprocess         *subprocess = NULL;
+        GInputStream        *input_stream = NULL;
+        GDataInputStream    *data_stream = NULL;
         GError              *error = NULL;
 
         char     *auth_file;
@@ -224,7 +222,6 @@ spawn_x_server (State        *state,
 
         arguments = g_ptr_array_new ();
         launcher = g_subprocess_launcher_new (G_SUBPROCESS_FLAGS_STDIN_INHERIT);
-        g_subprocess_launcher_setenv (launcher, "DBUS_SESSION_BUS_ADDRESS", state->bus_address, TRUE);
         g_subprocess_launcher_take_fd (launcher, pipe_fds[1], DISPLAY_FILENO);
 
         if (g_getenv ("XDG_VTNR") != NULL) {
@@ -363,14 +360,14 @@ static gboolean
 spawn_bus (State        *state,
            GCancellable *cancellable)
 {
-        GPtrArray           *arguments;
-        GSubprocessLauncher *launcher;
-        GSubprocess         *subprocess;
-        GInputStream        *input_stream;
-        GDataInputStream    *data_stream;
+        GPtrArray           *arguments = NULL;
+        GSubprocessLauncher *launcher = NULL;
+        GSubprocess         *subprocess = NULL;
+        GInputStream        *input_stream = NULL;
+        GDataInputStream    *data_stream = NULL;
         GError              *error = NULL;
         char                *bus_address_fd_string;
-        char                *bus_address;
+        char                *bus_address = NULL;
         gsize                bus_address_size;
 
         gboolean  is_running = FALSE;
@@ -392,7 +389,7 @@ spawn_bus (State        *state,
 
         bus_address_fd_string = g_strdup_printf ("%d", BUS_ADDRESS_FILENO);
 
-        g_ptr_array_add (arguments, DBUS_DAEMON);
+        g_ptr_array_add (arguments, "dbus-daemon");
 
         g_ptr_array_add (arguments, "--print-address");
         g_ptr_array_add (arguments, bus_address_fd_string);
@@ -407,7 +404,7 @@ spawn_bus (State        *state,
         g_ptr_array_free (arguments, TRUE);
 
         if (subprocess == NULL) {
-                g_debug ("could not start X server: %s", error->message);
+                g_debug ("could not start dbus-daemon: %s", error->message);
                 goto out;
         }
 
@@ -489,8 +486,8 @@ spawn_session (State        *state,
                gboolean      run_script,
                GCancellable *cancellable)
 {
-        GSubprocessLauncher *launcher;
-        GSubprocess         *subprocess;
+        GSubprocessLauncher *launcher = NULL;
+        GSubprocess         *subprocess = NULL;
         GError              *error = NULL;
         gboolean             is_running = FALSE;
         const char          *vt;
@@ -501,6 +498,7 @@ spawn_session (State        *state,
 
         g_subprocess_launcher_setenv (launcher, "DISPLAY", state->display_name, TRUE);
         g_subprocess_launcher_setenv (launcher, "XAUTHORITY", state->auth_file, TRUE);
+        g_subprocess_launcher_setenv (launcher, "DBUS_SESSION_BUS_ADDRESS", state->bus_address, TRUE);
 
         vt = g_getenv ("XDG_VTNR");
 
@@ -588,7 +586,7 @@ static gboolean
 register_display (State        *state,
                   GCancellable *cancellable)
 {
-        GdmDBusManager  *manager;
+        GdmDBusManager  *manager = NULL;
         GError          *error = NULL;
         gboolean         registered = FALSE;
         GVariantBuilder  details;
@@ -663,8 +661,8 @@ int
 main (int    argc,
       char **argv)
 {
-        State           *state;
-        GOptionContext  *context;
+        State           *state = NULL;
+        GOptionContext  *context = NULL;
         static char    **args = NULL;
         static gboolean  run_script = FALSE;
         static gboolean  allow_remote_connections = FALSE;
